@@ -156,8 +156,7 @@ def cas(settings, secrets, save, id):
     logger.info("Successful cas command")
 
 
-@cli.command(help="Collect files from CAS.")
-@click.argument("id",)
+@cli.command(help="Check configuration files")
 @click.option(
     "--settings",
     default=None,
