@@ -6,7 +6,6 @@ from .config import settings
 from .db import get_DB_client
 from .save import get_save_client
 from .utils import elapsed_time
-from .utils import print_table
 
 logger = logging.getLogger(__name__)
 
@@ -26,12 +25,17 @@ class Query:
         with elapsed_time as et:
             task = et.add_task("Running your query, elapsed time:")
             cnxn = self.db.set_up_connection()
-            df = pd.read_sql(query, cnxn)
+            df_chunks = pd.read_sql(query, cnxn, coerce_float=False, chunksize=20000)
             et.stop_task(task)
 
         logger.info("Finished running query")
 
-        print_table(df.head(50), "Your query first 50 results")
-        print(f"Saving result to {filename}")
-        logger.info(f"Saving result to {filename}")
-        self.sh.save_meta(df, filename)
+        print("Saving result in chunks of 20k rows")
+        prefix = ""
+        for i, df in enumerate(df_chunks):
+            print(f"Saving chunk {i+1}...")
+            if i > 0:
+                prefix = f"{i}-"
+            print(f"Saving result to {prefix+filename}.csv")
+            logger.info(f"Saving result to {prefix+filename}.csv")
+            self.sh.save_meta(df, prefix + filename)
